package com.tzld.piaoquan.api.remote;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.tzld.piaoquan.api.model.bo.VideoDetail;
import com.tzld.piaoquan.growth.common.component.HttpPoolClient;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.Objects;

@Slf4j
@Component
public class AigcApiService {

    @Autowired
    private HttpPoolClient httpPoolClient;

    @Value("${aigc.api.host:http://aigc-testapi.cybertogether.net/aigc}")
    private String aigcApiHost;

    @Value("${aigc.api.token:9ebfcb397e954c41986971f183eb1707}")
    private String aigcApiToken;

    private String getAigcPostParam(JSONObject params) {
        JSONObject baseInfo = JSONObject.parseObject("{\n" +
                "    \"token\": \"" + aigcApiToken + "\",\n" +
                "    \"appType\": 9,\n" +
                "    \"platform\": \"pc\",\n" +
                "    \"appVersionCode\": 1000,\n" +
                "    \"clientTimestamp\": 1,\n" +
                "    \"fid\": 1,\n" +
                "    \"loginUid\": 1,\n" +
                "    \"pageSource\": 1,\n" +
                "    \"requestId\": 1,\n" +
                "    \"rid\": 1,\n" +
                "    \"uid\": 1\n" +
                "}");
        JSONObject param = new JSONObject();
        param.put("params", params);
        param.put("baseInfo", baseInfo);
        return param.toJSONString();
    }

    public String generateQrcode(String uuid) {
        String url = aigcApiHost + "/publish/account/generateQrcode";
        JSONObject params = new JSONObject();
        params.put("uuid", uuid);
        try {
            String post = httpPoolClient.post(url, getAigcPostParam(params));
            JSONObject res = JSONObject.parseObject(post);
            JSONObject data = res.getJSONObject("data");
            return data.getString("qrcodeStr");
        } catch (Exception e) {
            log.error("getVideoDetailRequest error", e);
        }
        return null;
    }

    public String getAuthResult(String uuid) {
        String url = aigcApiHost + "/publish/account/authResult";
        JSONObject params = new JSONObject();
        params.put("uuid", uuid);
        try {
            String post = httpPoolClient.post(url, getAigcPostParam(params));
            JSONObject res = JSONObject.parseObject(post);
            if (Objects.isNull(res)) {
                return null;
            }
            JSONObject data = res.getJSONObject("data");
            return data.getString("id");
        } catch (Exception e) {
            log.error("getVideoDetailRequest error", e);
        }
        return null;
    }

    public JSONObject getAccountDetail(String publishAccountId) {
        String url = aigcApiHost + "/publish/account/getAuthResult";
        JSONObject params = new JSONObject();
        params.put("id", publishAccountId);
        try {
            String post = httpPoolClient.post(url, getAigcPostParam(params));
            JSONObject res = JSONObject.parseObject(post);
            return res.getJSONObject("data");
        } catch (Exception e) {
            log.error("getVideoDetailRequest error", e);
        }
        return null;
    }
}
